@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2015-2017 Montel Laurent <montel@kde.org>
+  Copyright (c) 2015-2018 Montel Laurent <montel@kde.org>
 
   This library is free software; you can redistribute it and/or modify it
   under the terms of the GNU Library General Public License as published by
@@ -35,7 +35,6 @@ KDebugSettingsDialogTest::KDebugSettingsDialogTest(QObject *parent)
 
 KDebugSettingsDialogTest::~KDebugSettingsDialogTest()
 {
-
 }
 
 void KDebugSettingsDialogTest::shouldHaveDefaultValue()
@@ -43,14 +42,14 @@ void KDebugSettingsDialogTest::shouldHaveDefaultValue()
     KDebugSettingsDialog dlg;
     QDialogButtonBox *buttonBox = dlg.findChild<QDialogButtonBox *>(QStringLiteral("buttonbox"));
     QVERIFY(buttonBox);
-    QCOMPARE(buttonBox->standardButtons(), QDialogButtonBox::Ok | QDialogButtonBox::Cancel | QDialogButtonBox::Help | QDialogButtonBox::Apply);
+    QCOMPARE(buttonBox->standardButtons(), QDialogButtonBox::RestoreDefaults | QDialogButtonBox::Ok | QDialogButtonBox::Cancel | QDialogButtonBox::Help | QDialogButtonBox::Apply);
     QTabWidget *tab = dlg.findChild<QTabWidget *>(QStringLiteral("tabwidget"));
     QVERIFY(tab);
     for (int i = 0; i < tab->count(); ++i) {
         const QString objName = tab->widget(i)->objectName();
-        const bool hasCorrectName = (objName == QStringLiteral("kdeapplicationsettingspage")) ||
-                                    (objName == QStringLiteral("customsettingspage")) ||
-                                    (objName == QStringLiteral("environmentsettingsrulespage"));
+        const bool hasCorrectName = (objName == QStringLiteral("kdeapplicationsettingspage"))
+                                    || (objName == QStringLiteral("customsettingspage"))
+                                    || (objName == QStringLiteral("environmentsettingsrulespage"));
         QVERIFY(hasCorrectName);
     }
     QPushButton *saveAs = buttonBox->findChild<QPushButton *>(QStringLiteral("saveas_button"));
