@@ -63,7 +63,7 @@ LoggingCategory::LoggingType canDisplayType(const QMap<KDebugSettingsUtil::LoadL
     } else if (debug == KDebugSettingsUtil::LoadLoggingCategory::Enabled
                && warning == KDebugSettingsUtil::LoadLoggingCategory::Enabled
                && critical == KDebugSettingsUtil::LoadLoggingCategory::Enabled) {
-        return LoggingCategory::Debug;
+        return LoggingCategory::Undefined;
     } else if (info == KDebugSettingsUtil::LoadLoggingCategory::Enabled
                && warning == KDebugSettingsUtil::LoadLoggingCategory::Enabled
                && critical == KDebugSettingsUtil::LoadLoggingCategory::Enabled) {
@@ -116,7 +116,7 @@ void LoadCategoriesJob::start()
 
         bool foundInConfigFile = false;
         for (KDebugSettingsUtil::LoadLoggingCategory cat : qAsConst(qtCategories)) {
-            if (cat.logName == kdeCat.logName) {
+            if (cat.logName == kdeCat.categoryName) {
                 LoggingCategory tmp;
                 LoggingCategory::LoggingType newType = canDisplayType(cat.loggingTypes);
                 if (newType != LoggingCategory::Undefined) {
@@ -125,8 +125,9 @@ void LoadCategoriesJob::start()
                         tmp.enabled = false;
                     }
                     tmp.description = kdeCat.description;
-                    tmp.logName = kdeCat.logName;
-                    tmp.defaultCategoryType = KDebugSettingsUtil::convertCategoryTypeFromString(kdeCat.defaultCategory);
+                    tmp.categoryName = kdeCat.categoryName;
+                    tmp.defaultSeverityType = KDebugSettingsUtil::convertCategoryTypeFromString(kdeCat.defaultSeverity);
+                    tmp.identifierName = kdeCat.identifierName;
 
                     mQtKdeCategories.append(tmp);
                     foundInConfigFile = true;
@@ -141,9 +142,10 @@ void LoadCategoriesJob::start()
         if (!foundInConfigFile) {
             LoggingCategory tmp;
             tmp.description = kdeCat.description;
-            tmp.logName = kdeCat.logName;
-            tmp.loggingType = KDebugSettingsUtil::convertCategoryTypeFromString(kdeCat.defaultCategory);
-            tmp.defaultCategoryType = KDebugSettingsUtil::convertCategoryTypeFromString(kdeCat.defaultCategory);
+            tmp.categoryName = kdeCat.categoryName;
+            tmp.loggingType = KDebugSettingsUtil::convertCategoryTypeFromString(kdeCat.defaultSeverity);
+            tmp.defaultSeverityType = KDebugSettingsUtil::convertCategoryTypeFromString(kdeCat.defaultSeverity);
+            tmp.identifierName = kdeCat.identifierName;
             mQtKdeCategories.append(tmp);
         }
     }
@@ -155,7 +157,7 @@ void LoadCategoriesJob::start()
             i.next();
             if (i.value() != KDebugSettingsUtil::LoadLoggingCategory::UnknownStatus) {
                 LoggingCategory tmp;
-                tmp.logName = cat.logName;
+                tmp.categoryName = cat.logName;
                 switch (i.key()) {
                 case KDebugSettingsUtil::LoadLoggingCategory::Unknown:
                     tmp.loggingType = LoggingCategory::Undefined;
