@@ -37,10 +37,10 @@ struct LoggingCategory {
     };
 
     LoggingCategory();
-
-    explicit LoggingCategory(const QString &description, const QString &logName, LoggingType loggingType, bool enabled)
+    explicit LoggingCategory(const QString &description, const QString &logName, LoggingType loggingType, const QString &identifier, bool enabled)
         : description(description)
-        , logName(logName)
+        , categoryName(logName)
+        , identifierName(identifier)
         , loggingType(loggingType)
         , enabled(enabled)
     {
@@ -54,9 +54,10 @@ struct LoggingCategory {
     Q_REQUIRED_RESULT QString createCustomRule() const;
 
     QString description;
-    QString logName;
+    QString categoryName;
+    QString identifierName;
     LoggingType loggingType = Info;
-    LoggingType defaultCategoryType = Info;
+    LoggingType defaultSeverityType = Info;
     bool enabled = true;
 };
 QDebug operator<<(QDebug debug, const LoggingCategory &cat);
